VZVirtioConsoleDeviceDelegate

Trait VZVirtioConsoleDeviceDelegate 

pub unsafe trait VZVirtioConsoleDeviceDelegate: NSObjectProtocol {
    // Provided methods
    unsafe fn consoleDevice_didOpenPort(
        &self,
        console_device: &VZVirtioConsoleDevice,
        console_port: &VZVirtioConsolePort,
    )
       where Self: Sized + Message { ... }
    unsafe fn consoleDevice_didClosePort(
        &self,
        console_device: &VZVirtioConsoleDevice,
        console_port: &VZVirtioConsolePort,
    )
       where Self: Sized + Message { ... }
}
Available on crate feature VZVirtioConsoleDevice only.
Delegate object for VZVirtioConsoleDevice.

A class conforming to the VZVirtioConsoleDeviceDelegate protocol can provide methods that notify when a console port is opened or closed in the virtual machine.

See: VZVirtioConsoleDevice

See: VZVirtioConsolePort

See also Apple’s documentation

Provided Methods

unsafe fn consoleDevice_didOpenPort( &self, console_device: &VZVirtioConsoleDevice, console_port: &VZVirtioConsolePort, )
where Self: Sized + Message,

Available on crate features VZConsoleDevice and VZVirtioConsolePort only.

Invoked when a guest process has opened a Virtio console port.

Parameter consoleDevice: The console port’s console device.

Parameter consolePort: The console port that has been opened.

Extra care should be taken to ensure that any pending data from the VZVirtioConsolePort attachment has been processed or flushed before communicating with a new virtual machine process.

unsafe fn consoleDevice_didClosePort( &self, console_device: &VZVirtioConsoleDevice, console_port: &VZVirtioConsolePort, )
where Self: Sized + Message,

Available on crate features VZConsoleDevice and VZVirtioConsolePort only.

Invoked when a guest process has closed a Virtio console port.

Parameter consoleDevice: The console port’s console device.

Parameter consolePort: The console port that has been closed.

It is recommended to finish processing or flushing any remaining data from the VZVirtioConsolePort attachment after a port has been closed.